aboutsummaryrefslogtreecommitdiffstats
path: root/resources/jquery.ui/jquery.ui.progressbar.js
diff options
context:
space:
mode:
authorSam Reed <reedy@users.mediawiki.org>2011-10-03 21:01:18 +0000
committerSam Reed <reedy@users.mediawiki.org>2011-10-03 21:01:18 +0000
commit186d083be804d2479db3a3c7fce59aaa3e9a6469 (patch)
treeabfb4953cdf2f1abfdee71daa5129354ac347e7b /resources/jquery.ui/jquery.ui.progressbar.js
parent7fddff5355e00995f5c25fad48ac1ad9189d267a (diff)
downloadmediawikicore-186d083be804d2479db3a3c7fce59aaa3e9a6469.tar.gz
mediawikicore-186d083be804d2479db3a3c7fce59aaa3e9a6469.zip
Update jquery.ui to 1.8.16
Added new Datepicker languages where appropriate (ie stuff we support)
Notes
Notes: http://mediawiki.org/wiki/Special:Code/MediaWiki/98808
Diffstat (limited to 'resources/jquery.ui/jquery.ui.progressbar.js')
-rw-r--r--resources/jquery.ui/jquery.ui.progressbar.js5
1 files changed, 3 insertions, 2 deletions
diff --git a/resources/jquery.ui/jquery.ui.progressbar.js b/resources/jquery.ui/jquery.ui.progressbar.js
index c432132a5ff6..5b199b2a3e88 100644
--- a/resources/jquery.ui/jquery.ui.progressbar.js
+++ b/resources/jquery.ui/jquery.ui.progressbar.js
@@ -1,5 +1,5 @@
/*
* jQuery UI Progressbar 1.8.11
*
* Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
* Dual licensed under the MIT or GPL Version 2 licenses.
@@ -95,6 +95,7 @@ $.widget( "ui.progressbar", {
}
this.valueDiv
+ .toggle( value > this.min )
.toggleClass( "ui-corner-right", value === this.options.max )
.width( percentage.toFixed(0) + "%" );
this.element.attr( "aria-valuenow", value );
@@ -102,7 +103,7 @@ $.widget( "ui.progressbar", {
});
$.extend( $.ui.progressbar, {
- version: "1.8.11"
+ version: "1.8.16"
});
})( jQuery );
@@ -1,5 +1,5 @@
/*
- * jQuery UI Progressbar 1.8.11
+ * jQuery UI Progressbar 1.8.16
*
* Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)